@@ -4,6 +4,67 @@ import hashlib
 import random
 
 
+def self_consistency_check() -> bool:
+    random.seed(0)
+    a = list(range(50))
+    random.shuffle(a)
+    if a == [
+        29,
+        12,
+        39,
+        42,
+        33,
+        7,
+        5,
+        41,
+        1,
+        26,
+        34,
+        0,
+        4,
+        36,
+        20,
+        14,
+        24,
+        43,
+        46,
+        45,
+        40,
+        11,
+        3,
+        17,
+        15,
+        10,
+        21,
+        27,
+        28,
+        49,
+        23,
+        35,
+        44,
+        9,
+        48,
+        6,
+        38,
+        18,
+        8,
+        47,
+        13,
+        37,
+        22,
+        30,
+        19,
+        25,
+        31,
+        32,
+        16,
+        2,
+    ]:
+        return True
+    else:
+        return False
+
+
 def check_hashseed() -> bool:
     """Need to set PYTHONHASHSEED=0 in env variable"""
     if hash("GOD") == -3890164749404887474:
@@ -16,9 +77,14 @@ def check_hashseed() -> bool:
 
 def permutate(input: str, key: str = None):
     """Input should be a space delimited word string"""
+    if not self_consistency_check():
+        print("Failed self consistency check. DO NOT PROCEED!")
+        quit(1)
+
     if not key:
         print("No key specified, will used the default: test")
         key = "test"
+
     words = [w.strip() for w in input.split()]
     wc = len(words)
     seq_orig = list(range(wc))
@@ -32,9 +98,14 @@ def permutate(input: str, key: str = None):
 
 def reverse_permutate(input: str, key: str = None):
     """Input should be a space delimited word string"""
+    if not self_consistency_check():
+        print("Failed self consistency check. DO NOT PROCEED!")
+        quit(1)
+
     if not key:
         print("No key specified, will used the default: test")
         key = "test"
+
     words = [w.strip() for w in input.split()]
     wc = len(words)
     seq_orig = list(range(wc))
